@@ -328,7 +328,7 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 	('sulaa', 'sw', [(None,'(.*C)AA','sulaa'),
 	                   ('nt','(.*n)tAA','kyntää'),
 		         ('tt','(.*t)tAA','autioittaa'),
-		         ('t','(.*h)tAA','kulahtaa'),
+		         ('t','(.*)tAA','kulahtaa'),
 		         ('k>','(.*C)kAA','purkaa')]),
 	('hohtaa', 'sw', [('tt','(.*t)tAA','jättää'),
 	                    ('t','(.*)tAA','hohtaa')]),
@@ -430,11 +430,10 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 			('>k','(.*)OtA','ulota'),
 			('>k','(.*)AtA','erata'),
 			('>k','(.*)etA','vaieta')]),
-	('haluta', 'ws', [(None,'(.*C)itA','selvitä'),
-			(None,'(.*gO)tA','bingota'),
-			(None,'(.*U)tA','haluta'),
+	('haluta', 'ws', [(None,'(.*V)tA','haluta'),
 			('ll','(.*l)litA','hellitä'),
 			('mm','(.*m)mitA','lämmitä'),
+			('t','(.*t)OtA','peitota'),
 			('p','(.*p)UtA','silputa'),
 			('v','(.*)vUtA','vivuta'),
 			('>k','(.*)itA','keritä')]),
@@ -459,7 +458,7 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 			('k','(.*k)AtA','pakata'),
 			('p','(.*p)AtA','pompata'),
 			('>k','(.*)AtA','taata')]),
-	('katketa', 'ws', [(None,'(.*[oe])tA','katketa'),
+	('katketa', 'ws', [(None,'(.*[oeU])tA','katketa'),
 	                     ('mm','(.*m)metA','kammeta'),
 			 ('ng','(.*n)getA','langeta'),
 			 ('t','(.*t)OtA','lotota'),
@@ -468,8 +467,9 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 			 ('d','(.*)detA','todeta'),
 			 ('j>k','(.*)jetA','lohjeta'),
 			 ('>k','(.*)OtA','saota'),
-			 ('>k','(.*)etA','poiketa')]),
-	('kohota', 'ws', [(None,'(.*O)tA','kohota'),
+			 ('>k','(.*)etA','poiketa'),
+			 ('ll','(.*l)lOtA','aallota')]),
+	('kohota', 'ws', [(None,'(.*[OU])tA','kohota'),
 	                    ('rr','(.*r)rOtA','irrota'),
 			('mm','(.*m)mOtA','kimmota'),
 			('ng','(.*n)gOtA','lingota'),
@@ -477,6 +477,7 @@ modern_classmap = [('valo', 'sw', [(None,'(.*)','valo'),
 			('p','(.*p)OtA','upota'),
 			('v','(.*r)vOtA','turvota'),
 			('k','(.*Vk)OtA','laota'),
+			('k','(.*Vk)UtA','takuta'),
 			('d','(.*)dOtA','kadota'),
 			('>k','(.*)OtA','laota')]),
 	('kihistä', '-', [(None,'(.*C)istA','kihistä')]),
